@@ -12,7 +12,14 @@ except:
     cupy = False
 
 
-def beam_search(model, X, params, return_alphas=False, eos_sym=0, null_sym=2, model_ensemble=False, n_models=0):
+def beam_search(model,
+                X,
+                params,
+                return_alphas=False,
+                eos_sym=0,
+                null_sym=2,
+                model_ensemble=False,
+                n_models=0):
     """
     Beam search method for Cond models.
     (https://en.wikibooks.org/wiki/Artificial_Intelligence/Search/Heuristic_search/Beam_search)
